###############################
Siglent Technologies Base Class
###############################

.. autoclass:: pymeasure.instruments.siglenttechnologies.siglent_spdbase.SPDBase
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.siglenttechnologies.siglent_spdbase.SPDSingleChannelBase
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.siglenttechnologies.siglent_spdbase.SPDChannel
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.siglenttechnologies.siglent_spdbase.SystemStatusCode
